@@ -39,7 +39,7 @@ def volatilidade(__ticker, **kwargs):
         elif __periodo == 12:
             __periodo_text = '1Ano'
         else:
-            __periodo_txt = __periodo + 'Meses'
+            __periodo_txt = str(__periodo) + 'Meses'
         # noinspection SpellCheckingInspection
         url = 'http://bvmf.bmfbovespa.com.br/cias-listadas/volatilidade-ativos/ResumoVolatilidadeAtivos.aspx?' \
               'metodo=padrao&' \
